@@ -8,7 +8,7 @@ require Exporter;
 use strict;
 use vars qw($VERSION @ISA);
 @ISA = qw(Exporter);
-$VERSION = '0.01'; # 
+$VERSION = '0.02'; # 
 
 sub new($;%) {
     my($sPkg, %hKey) = @_;
@@ -82,16 +82,16 @@ sub ValFmt($$$) {
         }
         elsif($iFmtIdx == 0x0F) { # Date: d-mmm-yy
             return sprintf("%d-%s-%02d", $iDay, 
-                ('', 'JAN', 'FEB', 'MAR', 'APR', 'JUN', 'JUL', 'AUG', 'SEP', 'NOV', 'DEC')[$iMon],
+                ('', 'JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN', 'JUL', 'AUG', 'SEP', 'OCT', 'NOV', 'DEC')[$iMon],
                 $iYear);
         }
         elsif($iFmtIdx == 0x10) { # Date: d-mmm
             return sprintf("%d-%s", $iDay, 
-                ('', 'JAN', 'FEB', 'MAR', 'APR', 'JUN', 'JUL', 'AUG', 'SEP', 'NOV', 'DEC')[$iMon]);
+                ('', 'JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN', 'JUL', 'AUG', 'SEP', 'OCT', 'NOV', 'DEC')[$iMon]);
         }
         elsif($iFmtIdx == 0x11) { # Date: mmm-yy
             return sprintf("%s-%02d", 
-                ('', 'JAN', 'FEB', 'MAR', 'APR', 'JUN', 'JUL', 'AUG', 'SEP', 'NOV', 'DEC')[$iMon],
+                ('', 'JAN', 'FEB', 'MAR', 'APR', 'MAY', 'JUN', 'JUL', 'AUG', 'SEP', 'OCT', 'NOV', 'DEC')[$iMon],
                 $iYear);
         }
         elsif($iFmtIdx == 0x12) { # Time: h:mm AM/PM
