@@ -1,14 +1,13 @@
 use strict;
-use warnings;
 use Spreadsheet::ParseExcel;
 use Spreadsheet::ParseExcel::FmtJapan;
-
+#0. Check ARGV
 if(($#ARGV< 0) or 
    (grep($ARGV[0] eq $_, ('euc', 'sjis', 'jis')) <= 0)) {
     print "USAGE: \n   > perl ", $0, " euc|sjis|jis\n";
     exit;
 }
-my $oExcel = Spreadsheet::ParseExcel->new;
+my $oExcel = new Spreadsheet::ParseExcel;
 
 #1. Make Formatter
 my $oFmtJ = Spreadsheet::ParseExcel::FmtJapan->new(Code => $ARGV[0]);
@@ -37,7 +36,8 @@ PrnBook($oBook);
 $oBook = $oExcel->Parse('Excel/AuthorK95.xls', $oFmtJ);
 PrnBook($oBook);
 
-sub PrnBook {
+sub PrnBook($$)
+{
     my($oBook) = @_;
     my($iR, $iC, $oWkS, $oWkC);
 
@@ -53,7 +53,7 @@ sub PrnBook {
             for(my $iC = $oWkS->{MinCol} ;
                             defined $oWkS->{MaxCol} && $iC <= $oWkS->{MaxCol} ; $iC++) {
                 $oWkC = $oWkS->{Cells}[$iR][$iC];
-                print "( $iR , $iC ) =>", $oWkC->Value, "\n" if($oWkC);
+                print "( $iR , $iC ) =>", $oWkC->Value, "\n";
             }
         }
     }
